/*
 * This document has been created by using VisualHAM
 * http://www.console-dev.de
 *
 * Author: Peter Schraut
 * Date..: 6th Nov. 2003
 *
 * Example shows how to use HEL's splash-screen function
 *
*/
#include <mygba.h>
 
// include hel header
#include <hel.h>

#include "gfx/SplashHEL.pal.c"
#include "gfx/SplashHEL.raw.c"

#include "gfx/SplashSomeText.pal.c"
#include "gfx/SplashSomeText.raw.c"

/*********************************************************************************
 * Program entry point
 ********************************************************************************/
int main(void)
{
    // Initialize HAMlib
    // Then we call the single most important function of ham, ham_Init .
    // This function must be called first thing when working with HAMlib,
    // because all ham_* functions will only work correctly after this has been called.
    // Behaviour of HAMlib is undefined if you comment this out.
    ham_Init();
    
    // Set to mode 4. hel_Splash() works only in bitmap-modes, these
    // are mode 3, 4 and 5
    ham_SetBgMode(4);
    
    // Show the "SomeText" splashscreen.
    // Fade in from black, display screen a moment and then
    // fade out to black again ...
    hel_Splash((void*)SplashSomeText_Bitmap,    // pBitmap
               (void*)SplashSomeText_Palette,   // pPalette
               SPLASH_TYPE_BLACK,               // SplashTypeIn
               SPLASH_TYPE_BLACK,               // SplashTypeOut
               6,                               // FadeInSpeed
               6,                               // FadeOutSpeed
               40,                              // WaitFrames
               16);                             // AfterWaitFrames    
    
    // Show the HEL splashscreen.
    // Fade in from black, display screen a moment and then
    // fade out to white ...
    hel_Splash((void*)SplashHEL_Bitmap,         // pBitmap
               (void*)SplashHEL_Palette,        // pPalette
               SPLASH_TYPE_BLACK,               // SplashTypeIn
               SPLASH_TYPE_WHITE,               // SplashTypeOut
               6,                               // FadeInSpeed
               6,                               // FadeOutSpeed
               40,                              // WaitFrames
               0);                              // AfterWaitFrames
     
    // The previous hel_Splash() call cleared Video and Palette RAM, so it's empty now.
    // We specify NULL for pBitmap and pPalette so it knows not to
    // store a bitmap or palette anymore.
    // now we fade the empty screen from white to black.
    hel_Splash((void*)NULL,                     // pBitmap
               (void*)NULL,                     // pPalette
               SPLASH_TYPE_WHITE,               // SplashTypeIn
               SPLASH_TYPE_BLACK,               // SplashTypeOut
               16,                              // FadeInSpeed
                6,                              // FadeOutSpeed
                0,                              // WaitFrames
               16);                             // AfterWaitFrames
               
    // Sets the GBAs BGMode to the value specified in bgno
    ham_SetBgMode(0);
    
    // Init the Text display system on the bg of your choice
    // This function must be called if you want to use HAMlibs text display system.
    // After calling this, you can use ham_DrawText and ham_SetTextCol.
    ham_InitText(0);
    
    // Draw some text
    ham_DrawText(1, 1, "that was the splashscreen");
    
    // infinite loop
    while(1);
    
    return 0;
}

/* END OF FILE */
